==> peony-extensions_4.10.0.0.orig.tar.gz: peony-extensions-4.10.0.0/peony-share/app/translations/peony-share-extension_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AdvancedSharePage</name>
    <message>
        <location filename="../advanced-share-page.cpp" line="58"/>
        <source>Advanced share</source>
        <translation>Partage avancé</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="109"/>
        <source>Samba set user password</source>
        <translation>Samba set le mot de passe de l’utilisateur</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="107"/>
        <source>Samba password:</source>
        <translation>Mot de passe de la samba :</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="117"/>
        <location filename="../advanced-share-page.cpp" line="129"/>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="117"/>
        <source>Samba set password failed, Please re-enter!</source>
        <translation>Échec de l’ensemble du mot de passe Samba, veuillez entrer à nouveau !</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="125"/>
        <source>Tips</source>
        <translation>Conseils</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="125"/>
        <source>The user has not set the samba password. If you need to log in to %1, you can set it in the upper right menu of the file manager</source>
        <translation>L’utilisateur n’a pas défini le mot de passe samba. Si vous avez besoin de vous connecter à %1, vous pouvez le définir dans le menu supérieur droit du gestionnaire de fichiers</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="129"/>
        <source>Shared configuration service exception, please confirm if there is an ongoing shared configuration operation, or please reset the share!</source>
        <translation>Exception au service de configuration partagée, veuillez confirmer s’il existe une opération de configuration partagée en cours, ou réinitialisez le partage !</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="270"/>
        <source>User</source>
        <translation>Utilisateur</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="270"/>
        <source>Writable</source>
        <translation>Inscriptible</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="270"/>
        <source>Readonly</source>
        <translation>Lecture seule</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="270"/>
        <source>Reject</source>
        <translation>Rejeter</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="365"/>
        <source>Share permission settings</source>
        <translation>Paramètres d’autorisation de partage</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="377"/>
        <source>delete</source>
        <translation>supprimer</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="394"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="411"/>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="412"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>NetUsershareHelper</name>
    <message>
        <source>Peony-Qt-Share-Extension</source>
        <translation type="vanished">共享</translation>
    </message>
</context>
<context>
    <name>Peony::SharePropertiesPagePlugin</name>
    <message>
        <location filename="../share-properties-page-plugin.h" line="44"/>
        <source>Peony Qt Share Extension</source>
        <translation>Extension de l’action Peony Qt</translation>
    </message>
    <message>
        <location filename="../share-properties-page-plugin.h" line="45"/>
        <source>Allow user share folders</source>
        <translation>Autoriser les dossiers de partage d’utilisateurs</translation>
    </message>
</context>
<context>
    <name>SharePage</name>
    <message>
        <location filename="../share-page.cpp" line="453"/>
        <source>Share folder</source>
        <translation>Partager le dossier</translation>
    </message>
    <message>
        <source>Share:</source>
        <translation type="vanished">共享:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="142"/>
        <source>The folder is currently shared in non-read-only mode, and setting up the share requires adding other people&apos;s write permissions to the current folder?</source>
        <translation>Le dossier est actuellement partagé en mode non lecture seule et la configuration du partage nécessite l’ajout des autorisations d’écriture d’autres personnes au dossier actuel ?</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="123"/>
        <location filename="../share-page.cpp" line="143"/>
        <location filename="../share-page.cpp" line="197"/>
        <source>question</source>
        <translation>question</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="145"/>
        <location filename="../share-page.cpp" line="199"/>
        <source>Confirm adding permissions</source>
        <translation>Confirmer l’ajout d’autorisations</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="146"/>
        <location filename="../share-page.cpp" line="200"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="108"/>
        <location filename="../share-page.cpp" line="113"/>
        <location filename="../share-page.cpp" line="174"/>
        <location filename="../share-page.cpp" line="183"/>
        <location filename="../share-page.cpp" line="229"/>
        <location filename="../share-page.cpp" line="239"/>
        <location filename="../share-page.cpp" line="283"/>
        <location filename="../share-page.cpp" line="320"/>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="108"/>
        <source>The share name must not contain %1, and cannot start with a dash (-) or whitespace, or end with whitespace.</source>
        <translation>Le nom du partage ne doit pas contenir %1 et ne peut pas commencer par un tiret (-) ou un espace, ni se terminer par un espace.</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="113"/>
        <source>The share name cannot be the same as the current user name</source>
        <translation>Le nom du partage ne peut pas être le même que le nom d’utilisateur actuel</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="123"/>
        <source>The share name is already used by other users. You can rename the folder and then set the share.</source>
        <translation>Le nom du partage est déjà utilisé par d’autres utilisateurs. Vous pouvez renommer le dossier, puis définir le partage.</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="196"/>
        <source>The folder is currently shared with anonymous access set, do I need to automatically increase the executable permissions of the current file and others in the ancestor directory?</source>
        <translation>Le dossier est actuellement partagé avec un accès anonyme défini, dois-je augmenter automatiquement les autorisations exécutables du fichier actuel et des autres fichiers du répertoire ancêtre ?</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="283"/>
        <source>Shared configuration service exception, please confirm if there is an ongoing shared configuration operation, or please reset the share!</source>
        <translation>Exception au service de configuration partagée, veuillez confirmer s’il existe une opération de configuration partagée en cours, ou réinitialisez le partage !</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="295"/>
        <source>Samba set user password</source>
        <translation>Samba set le mot de passe de l’utilisateur</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="293"/>
        <source>Samba password:</source>
        <translation>Mot de passe de la samba :</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="320"/>
        <source>Samba set password failed, Please re-enter!</source>
        <translation>Échec de l’ensemble du mot de passe Samba, veuillez entrer à nouveau !</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="421"/>
        <source>usershare</source>
        <translation>Partage d’utilisateurs</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="428"/>
        <location filename="../share-page.cpp" line="471"/>
        <source>share this folder</source>
        <translation>Partager ce dossier</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="428"/>
        <location filename="../share-page.cpp" line="478"/>
        <source>don`t share this folder</source>
        <translation>Ne pas partager ce dossier</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="504"/>
        <source>Share name:</source>
        <translation>Nom de l’action&#xa0;:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="509"/>
        <source>Read Only</source>
        <translation>Lecture seule</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="512"/>
        <source>Allow Anonymous</source>
        <translation>Autoriser l’anonymat</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="520"/>
        <source>Advanced Sharing</source>
        <translation>Partage avancé</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="505"/>
        <source>Comment:</source>
        <translation>Commentaire:</translation>
    </message>
</context>
</TS>

==> peony-extensions_4.20.0.0.orig.tar.gz: peony-extensions-4.20.0.0/peony-share/app/translations/peony-share-extension_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AdvancedSharePage</name>
    <message>
        <location filename="../advanced-share-page.cpp" line="59"/>
        <source>Advanced share</source>
        <translation>Partage avancé</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="111"/>
        <source>Samba set user password</source>
        <translation>Samba set le mot de passe de l’utilisateur</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="109"/>
        <source>Samba password:</source>
        <translation>Mot de passe de la samba :</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="119"/>
        <location filename="../advanced-share-page.cpp" line="131"/>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="119"/>
        <source>Samba set password failed, Please re-enter!</source>
        <translation>Échec de l’ensemble du mot de passe Samba, veuillez entrer à nouveau !</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="127"/>
        <source>Tips</source>
        <translation>Conseils</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="127"/>
        <source>The user has not set the samba password. If you need to log in to %1, you can set it in the upper right menu of the file manager</source>
        <translation>L’utilisateur n’a pas défini le mot de passe samba. Si vous avez besoin de vous connecter à %1, vous pouvez le définir dans le menu supérieur droit du gestionnaire de fichiers</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="131"/>
        <source>Shared configuration service exception, please confirm if there is an ongoing shared configuration operation, or please reset the share!</source>
        <translation>Exception au service de configuration partagée, veuillez confirmer s’il existe une opération de configuration partagée en cours, ou réinitialisez le partage !</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="274"/>
        <source>User</source>
        <translation>Utilisateur</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="274"/>
        <source>Writable</source>
        <translation>Inscriptible</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="274"/>
        <source>Readonly</source>
        <translation>Lecture seule</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="274"/>
        <source>Reject</source>
        <translation>Rejeter</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="371"/>
        <source>Share permission settings</source>
        <translation>Paramètres d’autorisation de partage</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="383"/>
        <source>delete</source>
        <translation>supprimer</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="400"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="417"/>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="418"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>NetUsershareHelper</name>
    <message>
        <source>Peony-Qt-Share-Extension</source>
        <translation type="vanished">共享</translation>
    </message>
</context>
<context>
    <name>Peony::SharePropertiesPagePlugin</name>
    <message>
        <location filename="../share-properties-page-plugin.h" line="44"/>
        <source>Peony Qt Share Extension</source>
        <translation>Extension de l’action Peony Qt</translation>
    </message>
    <message>
        <location filename="../share-properties-page-plugin.h" line="45"/>
        <source>Allow user share folders</source>
        <translation>Autoriser les dossiers de partage d’utilisateurs</translation>
    </message>
</context>
<context>
    <name>SharePage</name>
    <message>
        <location filename="../share-page.cpp" line="485"/>
        <source>Share folder</source>
        <translation>Partager le dossier</translation>
    </message>
    <message>
        <source>Share:</source>
        <translation type="vanished">共享:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="144"/>
        <source>The folder is currently shared in non-read-only mode, and setting up the share requires adding other people&apos;s write permissions to the current folder?</source>
        <translation>Le dossier est actuellement partagé en mode non lecture seule et la configuration du partage nécessite l’ajout des autorisations d’écriture d’autres personnes au dossier actuel ?</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="125"/>
        <location filename="../share-page.cpp" line="145"/>
        <location filename="../share-page.cpp" line="199"/>
        <source>question</source>
        <translation>question</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="147"/>
        <location filename="../share-page.cpp" line="201"/>
        <source>Confirm adding permissions</source>
        <translation>Confirmer l’ajout d’autorisations</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="148"/>
        <location filename="../share-page.cpp" line="202"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="110"/>
        <location filename="../share-page.cpp" line="115"/>
        <location filename="../share-page.cpp" line="176"/>
        <location filename="../share-page.cpp" line="185"/>
        <location filename="../share-page.cpp" line="231"/>
        <location filename="../share-page.cpp" line="241"/>
        <location filename="../share-page.cpp" line="285"/>
        <location filename="../share-page.cpp" line="325"/>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="110"/>
        <source>The share name must not contain %1, and cannot start with a dash (-) or whitespace, or end with whitespace.</source>
        <translation>Le nom du partage ne doit pas contenir %1 et ne peut pas commencer par un tiret (-) ou un espace, ni se terminer par un espace.</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="115"/>
        <source>The share name cannot be the same as the current user name</source>
        <translation>Le nom du partage ne peut pas être le même que le nom d’utilisateur actuel</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="125"/>
        <source>The share name is already used by other users. You can rename the folder and then set the share.</source>
        <translation>Le nom du partage est déjà utilisé par d’autres utilisateurs. Vous pouvez renommer le dossier, puis définir le partage.</translation>
    </message>
    <message>
        <source>The folder is currently shared with anonymous access set, do I need to automatically increase the executable permissions of the current file and others in the ancestor directory?</source>
        <translation type="vanished">Le dossier est actuellement partagé avec un accès anonyme défini, dois-je augmenter automatiquement les autorisations exécutables du fichier actuel et des autres fichiers du répertoire ancêtre ?</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="285"/>
        <source>Shared configuration service exception, please confirm if there is an ongoing shared configuration operation, or please reset the share!</source>
        <translation>Exception au service de configuration partagée, veuillez confirmer s’il existe une opération de configuration partagée en cours, ou réinitialisez le partage !</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="297"/>
        <source>Samba set user password</source>
        <translation>Samba set le mot de passe de l’utilisateur</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="295"/>
        <source>Samba password:</source>
        <translation>Mot de passe de la samba :</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="198"/>
        <source>The folder is currently shared with anonymous access set, do I need to automatically add executable permissions for the current file and all other members of the parent directory?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="325"/>
        <source>Samba set password failed, Please re-enter!</source>
        <translation>Échec de l’ensemble du mot de passe Samba, veuillez entrer à nouveau !</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="449"/>
        <source>usershare</source>
        <translation>Partage d’utilisateurs</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="456"/>
        <location filename="../share-page.cpp" line="501"/>
        <source>share this folder</source>
        <translation>Partager ce dossier</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="456"/>
        <location filename="../share-page.cpp" line="508"/>
        <source>don`t share this folder</source>
        <translation>Ne pas partager ce dossier</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="536"/>
        <source>Share name:</source>
        <translation>Nom de l’action&#xa0;:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="541"/>
        <source>Allow others to create and delete files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="vanished">Lecture seule</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="544"/>
        <source>Allow Anonymous</source>
        <translation>Autoriser l’anonymat</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="553"/>
        <source>Advanced Sharing</source>
        <translation>Partage avancé</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="537"/>
        <source>Comment:</source>
        <translation>Commentaire:</translation>
    </message>
</context>
</TS>
